==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/SAPDB/SQLStudio/WebQuery/StudioWeb_Definitions.hpp <==
/*


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/
#ifndef StudioWeb_DEFINITIONS_HPP
#define StudioWeb_DEFINITIONS_HPP

/*!**********************************************************************

  module: StudioWeb_Definitions.hpp

  -----------------------------------------------------------------------

  responsible:  WolfgangA

  special area: WebQuery

  description:  datatypes for WebQuery

  see also:

  -----------------------------------------------------------------------

  copyright:                Copyright by SAP AG, 2000

************************************************************************/

/*=======================================================================
 *  INCLUDES
 *=====================================================================*/



//#include "SAPDB/SQLStudio/OAL/StudioOAL_Common.h"
//#include "SAPDB/SQLStudio/OAL/StudioOAL_Error.hpp"
//#include "SAPDB/SQLStudio/OAL/StudioOAL_Result.hpp"
#include "SAPDB/SAPDBCommon/SAPDB_DynamicUTF8String.hpp"

#define QUOTETAG 		"&quot;"

#define QUOTE			"\""

#define SPACE			" "

#define SPACETAG		"%20"

#define  WQ_LOGON_FRAME_PATH "wqlogon.htm"

#define  WQ_MAINFRAME_PATH  "wqframe.htm"

#define  WQ_MAINFRAMENOTREE_PATH  "wqframenotree.htm";

#define  WQ_TREEBUTTONS_PATH "wqtreebuttons.htm"

const SAPDB_Int4 cnstLimitForLong = 128;

#define DISABLED_TRUE		"true"
#define DISABLED_FALSE		"false"

enum StudioWeb_FetchDirection
{
	StudioWeb_FetchDirNone = 0,
	StudioWeb_FetchDirFirst = 1,
    StudioWeb_FetchDirPrevious = 2,
    StudioWeb_FetchDirNext = 3,    
	StudioWeb_FetchDirLast =4
};

enum StudioWeb_DisableButton
{
	StudioWeb_DisableNone = 0,
	StudioWeb_DisableFirst = 1,
    StudioWeb_DisablePrevious = 2,
    StudioWeb_DisableNext = 3,    
	StudioWeb_DisableLast =4,
	StudioWeb_DisableNextLast = 5,
	StudioWeb_DisableFirstPrev = 6
};

   
#endif

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/SAPDB/SQLStudio/WebQuery/StudioWeb_Definitions.hpp <==
/*


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end


*/
#ifndef StudioWeb_DEFINITIONS_HPP
#define StudioWeb_DEFINITIONS_HPP

/*!**********************************************************************

  module: StudioWeb_Definitions.hpp

  -----------------------------------------------------------------------

  responsible:  WolfgangA

  special area: WebQuery

  description:  datatypes for WebQuery

  see also:

  -----------------------------------------------------------------------

  copyright:                Copyright by SAP AG, 2000

************************************************************************/

/*=======================================================================
 *  INCLUDES
 *=====================================================================*/




#include "SAPDB/ToolsCommon/Tools_DynamicUTF8String.hpp"

#define QUOTETAG 		"&quot;"

#define QUOTE			"\""

#define SPACE			" "

#define SPACETAG		"%20"

#define  WQ_LOGON_FRAME_PATH "wqlogon.htm"

#define  WQ_MAINFRAME_PATH  "wqframe.htm"

#define  WQ_MAINFRAMENOTREE_PATH  "wqframenotree.htm";

#define  WQ_TREEBUTTONS_PATH "wqtreebuttons.htm"

const SAPDB_Int4 cnstLimitForLong = 128;

#define DISABLED_TRUE		"true"
#define DISABLED_FALSE		"false"

enum StudioWeb_FetchDirection
{
	StudioWeb_FetchDirNone = 0,
	StudioWeb_FetchDirFirst = 1,
    StudioWeb_FetchDirPrevious = 2,
    StudioWeb_FetchDirNext = 3,    
	StudioWeb_FetchDirLast =4
};

enum StudioWeb_DisableButton
{
	StudioWeb_DisableNone = 0,
	StudioWeb_DisableFirst = 1,
    StudioWeb_DisablePrevious = 2,
    StudioWeb_DisableNext = 3,    
	StudioWeb_DisableLast =4,
	StudioWeb_DisableNextLast = 5,
	StudioWeb_DisableFirstPrev = 6
};

   
#endif
